..
    Copyright (C) 2020 CERN.

    Invenio-Vocabularies is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version 0.1.5 (released 2020-12-11)

- Bug fixes in contrib vocabulary

Version 0.1.4 (released 2020-12-11)

- Add subjects vocabulary

Version 0.1.3 (released 2020-12-11)

- Include csv vocabularies data

Version 0.1.2 (released 2020-12-11)

- CI changes

Version 0.1.1 (released 2020-12-11)

- Add vocabulary import command

Version 0.1.0 (released 2020-12-08)

- Initial public release.
